@@ -16,8 +16,7 @@ from durus.connection import Connection
 from durus.error import ConflictError
 
 if sys.version < "2.6":
-    from md5 import md5
-    md5_new = md5.new
+    from md5 import new as md5_new
 else:
     from hashlib import md5 as md5_new
 
